@@ -75,7 +75,8 @@ FortranMagics::FortranMagics() :
     legend_todo_(false),
     symbolinput_todo_(false),
     matrixinput_todo_(false),
-    polyinput_todo_(false)
+    polyinput_todo_(false),
+    axisContainer_(0)
 
 {
     ASSERT(singleton_ == 0);
@@ -152,7 +153,9 @@ int FortranMagics::pclose(bool catch_exceptions) {
                 /***   Start clean-up  ***/
                 drivers_->dispatch(object);
                 drivers_->closeDrivers();
+                drivers_->clear();
 
+                //cout << "deleting object" << endl;
                 delete root_;
                 delete drivers_;
                 delete output_;
@@ -219,6 +222,11 @@ void FortranMagics::subpage() {
     top()->push_back(axisContainer_);
     axisContainer_->getReady();
     push(axisContainer_);
+
+    while (!axis_.empty()) {
+            axisContainer_->push_back(axis_.top());
+            axis_.pop();
+    }
 }
 
 void FortranMagics::page() {
@@ -368,8 +376,10 @@ void FortranMagics::actions() {
         Action action = actions_.top();
         (this->*action)();
         actions_.pop();
+        
         empty_ = false;
     }
+   
 }
 
 void FortranMagics::pcoast() {
@@ -402,6 +412,11 @@ void FortranMagics::pobs() {
         action_->visdef(new ObsPlotting());
         return;
     }
+    action_ = new VisualAction();
+    action_->data(new ObsJSon());
+    top()->push_back(action_);
+    action_->visdef(new ObsPlotting());
+    return;
 }
 
 #include "MatrixTestDecoder.h"
@@ -418,10 +433,7 @@ void FortranMagics::ptest() {
 void FortranMagics::finish() {
     if (!empty_) {
         actions();  // The flag to force the generation of the plot has been set!
-        while (!axis_.empty()) {
-            axisContainer_->push_back(axis_.top());
-            axis_.pop();
-        }
+        
     }
 
     if (!axisContainer_)
@@ -962,7 +974,8 @@ void FortranMagics::epsshading() {
 }
 
 void FortranMagics::paxis() {
-    actions();
+   
+   
     try {
         string orientation;
 
@@ -971,12 +984,20 @@ void FortranMagics::paxis() {
         if (magCompare(orientation, "vertical")) {
             Axis* vaxis = new VerticalAxis();
             MagLog::dev() << *vaxis << "\n";
-            top()->push_back(vaxis);
+            if (axisContainer_)
+                axisContainer_->push_back(vaxis);
+            else 
+                axis_.push(vaxis);
+            
         }
         else {
             Axis* haxis = new HorizontalAxis();
             MagLog::dev() << *haxis << "\n";
-            top()->push_back(haxis);
+            if (axisContainer_)
+                axisContainer_->push_back(haxis);
+            else 
+                axis_.push(haxis);
+            
         }
     }
     catch (MagicsException& e) {
