@@ -50,6 +50,8 @@ public:
         fromto_(false),
         borderColour_("black"),
         meanSet_(false),
+        userMin_(false),
+        userMax_(false),
         histogram_(0) {}
     LegendEntry(double label) :
         last_(false),
@@ -59,6 +61,8 @@ public:
         fromto_(false),
         borderColour_("black"),
         meanSet_(false),
+        userMin_(false),
+        userMax_(false),
         histogram_(0) {
         format(label);
     }
@@ -70,6 +74,8 @@ public:
         fromto_(false),
         borderColour_("black"),
         meanSet_(false),
+        userMin_(false),
+        userMax_(false),
         histogram_(0) {
         format(min, max);
     }
@@ -138,10 +144,12 @@ public:
     void minText(const string& text) {
         minText_ = text;
         label_   = text;
+        userMin_ = true;
     }
     void maxText(const string& text) {
         maxText_ = text;
         label_   = text;
+        userMax_ = true;
     }
     double min() { return from_; }
     double max() { return to_; }
@@ -161,6 +169,8 @@ protected:
     string units_;
     string minText_;
     string maxText_;
+    bool userMin_;
+    bool userMax_;
 
     double from_;
     double to_;
@@ -277,19 +287,13 @@ public:
 class DoubleLineEntry : public LegendEntry {
 public:
     DoubleLineEntry(const string label, Polyline* line1 = 0, Polyline* line2 = 0) :
-        LegendEntry(label),
-        line1_(line1),
-        line2_(line2) {}
+        LegendEntry(label), line1_(line1), line2_(line2) {}
     DoubleLineEntry(double label, Polyline* line1 = 0, Polyline* line2 = 0) :
-        LegendEntry(label),
-        line1_(line1),
-        line2_(line2) {
+        LegendEntry(label), line1_(line1), line2_(line2) {
         format(label);
     }
     DoubleLineEntry(double min, double max, Polyline* line1 = 0, Polyline* line2 = 0) :
-        LegendEntry(min, max),
-        line1_(line1),
-        line2_(line2) {
+        LegendEntry(min, max), line1_(line1), line2_(line2) {
         format(min, max);
     }
     void set(const PaperPoint&, BasicGraphicsObjectContainer&);
