@@ -24,12 +24,7 @@
 using namespace magics;
 
 Label::Label(const string& label) :
-    label_(label),
-    justification_(MCENTRE),
-    verticalAlign_(MBASE),
-    angle_(0.),
-    blanking_(false),
-    visible_(false) {}
+    label_(label), justification_(MCENTRE), verticalAlign_(MBASE), angle_(0.), blanking_(false), visible_(false) {}
 
 
 Label::Label(double label) :
