@@ -319,8 +319,6 @@ ostream& MagLog::userInfo() {
 
 
 void MagLog::broadcast() {
-    // disable broadcast
-
     bool more = true;
     for (vector<MagLogObserver*>::iterator observer = log_.listeners_.begin(); observer != log_.listeners_.end();
          ++observer) {
@@ -351,6 +349,7 @@ void MagLog::broadcast() {
     log_.errorstream_.str("");
     log_.infostream_.str("");
     log_.progressstream_.str("");
+    log_.debugstream_.str("");
 }
 
 ostream& MagLog::fatal() {
