@@ -543,13 +543,31 @@ void Proj4Projection::projectionSimple() {
     min_pcy_ = min_latitude_;
     max_pcx_ = max_longitude_;
     max_pcy_ = max_latitude_;
+
+    cout << definition_ << endl;
+
+    int error;
+    
     helper_->revert(min_longitude_, min_latitude_);
-    helper_->revert(max_longitude_, max_latitude_);
+    error = helper_->revert(max_longitude_, max_latitude_);
+    double x = max_longitude_;
+    double y = max_latitude_;
+
+    helper_->convert(x, y);
+
+    // cout << "[" << min_pcx_ << " " << min_pcy_ << "]-->[" << max_pcx_ << " " << max_pcy_ << "]" << endl;
+    // cout << "[" << min_longitude_ << " " << min_latitude_ << "]-->[" << max_longitude_ << " " << max_latitude_ << "]" << endl;
+    // cout << "[" << max_longitude_ << " " << max_latitude_ << "]-->[" << x << " " << y << "] --> " << error <<  endl;
 
     if (max_longitude_ < 0) {
         max_longitude_ += 360.;
     }
+    
 
+   
+
+
+    
     magics::Polyline box;
     box.box(PaperPoint(min_pcx_, min_pcy_), PaperPoint(max_pcx_, max_pcy_));
 
@@ -616,6 +634,26 @@ void Proj4Projection::geos() {
     for (vector<double>::reverse_iterator lon = last->second.rbegin(); lon != last->second.rend(); ++lon) {
         add(*lon, last->first);
     }
+    
+   
+    gridMinLat_ = -90;
+    gridMinLon_ = vertical_longitude_ -180;
+    gridMaxLat_ = 90;
+    gridMaxLon_ = vertical_longitude_ + 180;
+
+
+    // Hre we have to make sure that the global area is defined between -180 and 180.
+
+    if ( gridMaxLon_ > 180 ) {
+        gridMaxLon_ = 180;
+        gridMinLon_ = std::min(gridMaxLon_ - 360, gridMinLon_);
+    }
+    if ( gridMinLon_ < -180 ) {
+        gridMinLon_ = -180;
+        gridMaxLon_ = std::max(gridMinLon_ + 360, gridMaxLon_);
+    }
+    
+    cout << gridMinLon_ << " --> " << gridMaxLon_ << endl;
 }
 
 magics::Polyline& Proj4Projection::getSimplePCBoundingBox() const {
@@ -715,6 +753,11 @@ void Proj4Projection::tpers() {
 
     userEnveloppe_->push_back(userEnveloppe_->front());
     PCEnveloppe_->push_back(PCEnveloppe_->front());
+
+    gridMinLat_ = -90;
+    gridMinLon_ = -200;
+    gridMaxLat_ = 90;
+    gridMaxLon_ = 200;
 }
 
 void Proj4Projection::boundingBox(double& xmin, double& ymin, double& xmax, double& ymax) const {
@@ -722,11 +765,14 @@ void Proj4Projection::boundingBox(double& xmin, double& ymin, double& xmax, doub
         projection_ = Epsg::find(definition_);
         helper_     = new LatLonProjP(projection_->definition());
     }
+    
+
 
     ymin = gridMinLat_;
-    xmin = gridMinLon_ - 5;
-    ymax = gridMaxLat_;
+    xmin = gridMinLon_ - 5;  
+    ymax = gridMaxLat_;  
     xmax = gridMaxLon_ + 5;
+   
 }
 
 double Proj4Projection::getMinX() const {
