@@ -30,14 +30,7 @@ class UserPoint {
 public:
     UserPoint(double x, double y, double value = 0, bool missing = false, bool border = false,
               const string& name = "") :
-        x_(x),
-        y_(y),
-        value_(value),
-        name_(name),
-        high_(false),
-        low_(false),
-        missing_(missing),
-        border_(border) {}
+        x_(x), y_(y), value_(value), name_(name), high_(false), low_(false), missing_(missing), border_(border) {}
     // ~UserPoint() {}
     UserPoint() : x_(0), y_(0), value_(0), name_(""), high_(false), low_(false), missing_(false), border_(false) {}
 
