@@ -394,7 +394,7 @@ void GribDecoder::visit(Transformation& transformation) {
     try {
         decode();
     }
-    catch (MagicsException) {
+    catch (MagicsException&) {
         valid_ = true;
         decode1D();
     }
@@ -737,13 +737,8 @@ grib_handle* GribDecoder::open(grib_handle* grib, bool sendmsg) {
         return grib;
     }
 
-#ifdef MAGICS_ON_WINDOWS
-    int original_mode;
-    _get_fmode(&original_mode);
-    _set_fmode(_O_BINARY);
-#endif
 
-    FILE* file = fopen(file_name_.c_str(), "r");
+    FILE* file = fopen(file_name_.c_str(), "rb");
 
     if (!file) {
         ostringstream error;
@@ -767,9 +762,7 @@ grib_handle* GribDecoder::open(grib_handle* grib, bool sendmsg) {
         }
         entry_ = entries_.begin();
         fclose(file);
-#ifdef MAGICS_ON_WINDOWS
-        _set_fmode(original_mode);
-#endif
+
         return first;
     }
 
@@ -789,10 +782,6 @@ grib_handle* GribDecoder::open(grib_handle* grib, bool sendmsg) {
     }
     fclose(file);
 
-#ifdef MAGICS_ON_WINDOWS
-    _set_fmode(original_mode);
-#endif
-
     entry_ = entries_.end();
     return handle;
 }
@@ -1548,7 +1537,7 @@ void GribDecoder::visit(MetaDataVisitor& meta) {
 
 string GribDecoder::representation() {
     string grid = getstring("typeOfGrid");
-    string proj = getstring("projTargetString");
+    string proj = getstring("projTargetString", false);
 
 
     return (proj.size()) ? "proj" : grid;
