@@ -48,13 +48,19 @@ void TypedAccessor<F, T>::operator()(vector<T>& to, vector<size_t>& start, vecto
                                      NetVariable& var) const {
     vector<F> from(to.size());
     var.get(from, start, edges);
+
     // Convert the data....
     std::transform(from.begin(), from.begin() + to.size(), to.begin(), Convertor<F, T>(var));
+    // for (auto x = start.begin(); x != start.end(); ++x) {   cout << "start " << *x << endl; }
+    // for (auto x = edges.begin(); x != edges.end(); ++x) {   cout << "edges " << *x << endl; }
+    
 }
 
 template <class F, class T>
 void TypedAccessor<F, T>::get(vector<F>& from, vector<size_t>& start, vector<size_t>& edges, NetVariable& var) const {
     var.get(&from.front(), start, edges);
+    
+   
 }
 
 Netcdf::Netcdf(const string& path, const string& method) : file_(-1) {
@@ -151,10 +157,11 @@ int NetDimension::index(const string& val) {
 }
 
 int NetDimension::value(const string& val) {
+    
     if (variable_ != -1) {
         // int index = Index::get(variable_->type(), val, variable_->values(), variable_->num_vals());
         NetVariable var(name_, variable_, parent_, "index");
-
+    
         return var.find(val);
     }
 
@@ -288,8 +295,17 @@ string NetVariable::interpretTime(const string& val) {
 
 int NetVariable::find(const string& value) {
     // First , is the variable a time variable:
-    string val = interpretTime(value);
 
+    string val = value;
+   
+    try {
+        val = interpretTime(value);
+    }
+    catch (...) {
+        val = value;
+    }
+    
+   
 
     nc_type t = type();
     if (t == NC_DOUBLE) {
@@ -326,12 +342,33 @@ int NetVariable::find(const string& value) {
         values.resize(getSize());
         get(values);
         short dval = tonumber(val);
-        cout << "PRINT-->" << dval << endl;
         return ::find(dval, values);
     }
+    if (t == NC_CHAR) {
+        vector<size_t> dims;
+        getDimensions(dims);
+        for ( int i = 0; i < dims[0]; i++ ) {
+            char text[256];
+            nc_get_var_text(netcdf_, id_, text);
+            if (string(text) ==  val)       
+                return i;
 
+        }
+    }
 
-    return -1;
+    if (t == NC_STRING) {
+        int x = getSize();
+        char *values[x];
+        nc_get_var_string(netcdf_, id_, values);
+        for (int i = 0; i < x; i++) {
+           
+            if (string(values[i]) == val) 
+                return i; 
+        }
+        
+    }
+    
+    return 0;
 }
 
 
@@ -398,3 +435,4 @@ static TypedAccessor<unsigned short, double> short_double_accessor(NC_USHORT);
 static TypedAccessor<int, double> int_double_accessor(NC_INT);
 static TypedAccessor<float, double> float_double_accessor(NC_FLOAT);
 static TypedAccessor<double, double> double_double_accessor(NC_DOUBLE);
+
