@@ -1,22 +1,22 @@
 /*
  * (C) Copyright 1996-2016 ECMWF.
- * 
+ *
  * This software is licensed under the terms of the Apache Licence Version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
- * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
 /*! \file NetcdfMarsConvention.h
     \brief Definition of the Template class NetcdfMarsConvention.
-    
+
     Magics Team - ECMWF 2004
-    
+
     Started: Tue 17-Feb-2004
-    
+
     Changes:
-    
+
 */
 
 #ifndef NetcdfMarsConvention_H
@@ -28,28 +28,28 @@
 
 namespace magics {
 
-class NetcdfMarsConvention: public NetcdfConvention {
-
+class NetcdfMarsConvention : public NetcdfConvention {
 public:
-	NetcdfMarsConvention();
-	virtual ~NetcdfMarsConvention();
+    NetcdfMarsConvention();
+    virtual ~NetcdfMarsConvention();
 
 protected:
-     //! Method to print string about this class on to a stream of type ostream (virtual).
-	 virtual void print(ostream&) const; 
+    //! Method to print string about this class on to a stream of type ostream (virtual).
+    virtual void print(ostream&) const;
 
 private:
     //! Copy constructor - No copy allowed
-	NetcdfMarsConvention(const NetcdfMarsConvention&);
+    NetcdfMarsConvention(const NetcdfMarsConvention&);
     //! Overloaded << operator to copy - No copy allowed
-	NetcdfMarsConvention& operator=(const NetcdfMarsConvention&);
+    NetcdfMarsConvention& operator=(const NetcdfMarsConvention&);
 
-// -- Friends
+    // -- Friends
     //! Overloaded << operator to call print().
-	friend ostream& operator<<(ostream& s,const NetcdfMarsConvention& p)
-		{ p.print(s); return s; }
-
+    friend ostream& operator<<(ostream& s, const NetcdfMarsConvention& p) {
+        p.print(s);
+        return s;
+    }
 };
 
-} // namespace magics
+}  // namespace magics
 #endif
