@@ -4,8 +4,8 @@
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
  * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation nor
- * does it submit to any jurisdiction.
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
  */
 
 /*! \file NetcdfOrcaInterpretor.h
@@ -20,7 +20,9 @@
 */
 
 #include "NetcdfOrcaInterpretor.h"
+
 #include <limits>
+
 #include "Factory.h"
 #include "Layer.h"
 #include "NetcdfData.h"
@@ -30,10 +32,8 @@ using namespace magics;
 
 NetcdfOrcaInterpretor::NetcdfOrcaInterpretor() : matrix_(0) {}
 
-
 NetcdfOrcaInterpretor::~NetcdfOrcaInterpretor() {}
 
-
 bool NetcdfOrcaInterpretor::interpretAsMatrix(Matrix** data) {
     if (*data)
         return false;
@@ -43,7 +43,6 @@ bool NetcdfOrcaInterpretor::interpretAsMatrix(Matrix** data) {
     vector<size_t> dims;
     var.getDimensions(dims);
 
-
     int jin  = dims[dims.size() - 2];
     int iin  = dims[dims.size() - 1];
     int jout = jin;
@@ -53,11 +52,9 @@ bool NetcdfOrcaInterpretor::interpretAsMatrix(Matrix** data) {
 
     *data = matrix_;
 
-
     double missing = netcdf.getMissing(field_, missing_attribute_);
     typedef pair<int, int> point_type;
 
-
     vector<std::pair<point_type, pair<int, int> > > points;
 
     matrix_->missing(missing);
@@ -67,11 +64,9 @@ bool NetcdfOrcaInterpretor::interpretAsMatrix(Matrix** data) {
         map<string, string> first, last;
         setDimensions(dimension_, first, last);
 
-
         MagLog::debug() << "data[" << matrix_->size() << ":" << *std::min_element(matrix_->begin(), matrix_->end())
                         << ", " << offset_ << "\n";
 
-
         vector<double> latm;
         vector<double> lonm;
         vector<double> data;
@@ -83,11 +78,9 @@ bool NetcdfOrcaInterpretor::interpretAsMatrix(Matrix** data) {
         double minlat = *std::min_element(latm.begin(), latm.end());
         double maxlat = *std::max_element(latm.begin(), latm.end());
 
-
         double minlon = *std::min_element(lonm.begin(), lonm.end());
         double maxlon = *std::max_element(lonm.begin(), lonm.end());
 
-
         vector<double>& lon = matrix_->columnsAxis();
         vector<double>& lat = matrix_->rowsAxis();
 
@@ -104,7 +97,6 @@ bool NetcdfOrcaInterpretor::interpretAsMatrix(Matrix** data) {
             }
         }
 
-
         double lat11, lat12, lat21, lat22;
         double lon11, lon12, lon21, lon22;
         double val11, val12, val21, val22;
@@ -133,7 +125,6 @@ bool NetcdfOrcaInterpretor::interpretAsMatrix(Matrix** data) {
                 val21 = data[c + (iin * (r + 1))];
                 val22 = data[(c + 1) + (iin * (r + 1))];
 
-
                 minlon = std::min(lon11, lon12);
                 maxlon = std::max(lon11, lon12);
                 minlon = std::min(minlon, lon21);
@@ -141,7 +132,6 @@ bool NetcdfOrcaInterpretor::interpretAsMatrix(Matrix** data) {
                 minlon = std::min(minlon, lon22);
                 maxlon = std::max(maxlon, lon22);
 
-
                 bool shift = false;
 
                 if ((maxlon - minlon) > 360 - (maxlon - minlon)) {
@@ -159,7 +149,6 @@ bool NetcdfOrcaInterpretor::interpretAsMatrix(Matrix** data) {
                     maxlon     = std::max(maxlon, l22);
                 }
 
-
                 // Now we fill the matrix
                 for (int y = 0; y < lat.size(); ++y) {
                     if (lat[y] < minlat)
@@ -167,15 +156,11 @@ bool NetcdfOrcaInterpretor::interpretAsMatrix(Matrix** data) {
                     if (lat[y] > maxlat)
                         break;
 
-                    int i = ((minlon - lon[0]) / inci) - 1;
-                    if (i < 0 || i > (lon.size() - 10))
-                        i = 0;
-                    i = 0;
-                    for (int x = i; x < lon.size(); ++x) {
+                    for (int x = 0; x < lon.size(); ++x) {
                         double l = (shift && lon[x] < 0) ? lon[x] + 360 : lon[x];
                         if (l < minlon)
                             continue;
-                        if (l > maxlon + 1) {
+                        if (l > maxlon + inci) {
                             break;
                         }
 
@@ -206,12 +191,10 @@ bool NetcdfOrcaInterpretor::interpretAsMatrix(Matrix** data) {
                 }
             }
 
-
             matrix_->multiply(scaling_);
             matrix_->plus(offset_);
             matrix_->setMapsAxis();
 
-
             MagLog::dev() << *matrix_ << "\n";
         }
     }
@@ -223,7 +206,6 @@ bool NetcdfOrcaInterpretor::interpretAsMatrix(Matrix** data) {
     return true;
 }
 
-
 bool NetcdfOrcaInterpretor::interpretAsPoints(PointsList& points) {
     // later!
 
@@ -267,7 +249,6 @@ bool NetcdfOrcaInterpretor::interpretAsPoints(PointsList& points) {
     return true;
 }
 
-
 void NetcdfOrcaInterpretor::visit(ValuesCollector& vcp, PointsList&) {
     vcp.setCollected(true);
 
@@ -281,7 +262,6 @@ void NetcdfOrcaInterpretor::visit(ValuesCollector& vcp, PointsList&) {
     }
 }
 
-
 void NetcdfOrcaInterpretor::customisedPoints(const Transformation& transformation, const std::set<string>&,
                                              CustomisedPointsList& out, int thinning) {
     try {
@@ -324,7 +304,6 @@ void NetcdfOrcaInterpretor::print(ostream& out) const {
     out << "]";
 }
 
-
 NetcdfInterpretor* NetcdfOrcaInterpretor::guess(const NetcdfInterpretor& from) {
     if (from.field_.empty() && (from.x_component_.empty() || from.y_component_.empty()))
         return 0;
@@ -335,14 +314,15 @@ NetcdfInterpretor* NetcdfOrcaInterpretor::guess(const NetcdfInterpretor& from) {
 
     // get the attribute coordinates
 
-
     string coordinates = netcdf.getVariable(variable).getAttribute("coordinates", string(""));
     string latlon("lat lon");
     coordinates = coordinates.substr(0, latlon.size());
 
+
     if (coordinates == "lat lon" || coordinates == "lon lat") {
         NetcdfOrcaInterpretor* interpretor = new NetcdfOrcaInterpretor();
 
+
         interpretor->NetcdfInterpretor::copy(from);
         interpretor->latitude_  = "lat";
         interpretor->longitude_ = "lon";
@@ -355,5 +335,4 @@ NetcdfInterpretor* NetcdfOrcaInterpretor::guess(const NetcdfInterpretor& from) {
     return 0;
 }
 
-
 static SimpleObjectMaker<NetcdfOrcaInterpretor, NetcdfInterpretor> netcdf_geovalues_interpretor("orca");
