@@ -107,7 +107,7 @@ void TitleTemplate::decode() {
     FILE* in = fopen(filename.c_str(), "r");
 
     if (!in)
-        throw NoSuchFileException(filename);
+        throw CannotOpenFile(filename);
 
     do {
         size_t len = fread(buf, 1, sizeof(buf), in);
@@ -145,7 +145,7 @@ void TitleTemplate::print(ostream& out) const {
 
 bool TitleTemplate::verify(const GribDecoder& data) const {
     for (map<string, string>::const_iterator criter = criteria_.begin(); criter != criteria_.end(); ++criter) {
-        //#ifdef MAGICS_EXCEPTION
+
         try {
             MagLog::debug() << "Try  to create the MatchCriteria for " << criter->first << "\n";
             unique_ptr<MatchCriteria> object(SimpleObjectMaker<MatchCriteria>::create(criter->first));
@@ -157,9 +157,6 @@ bool TitleTemplate::verify(const GribDecoder& data) const {
             MagLog::warning() << "Can Not Create the MatchCriteria for " << criter->first << "\n";
             return false;
         }
-        //#else
-
-        //#endif
     }
     return true;
 }
