@@ -597,7 +597,7 @@ bool BaseDriver::renderCellArray(const Image&) const {
     return true;
 }
 
-bool BaseDriver::renderPixmap(MFloat, MFloat, MFloat, MFloat, int, int, unsigned char*, int, bool) const {
+bool BaseDriver::renderPixmap(MFloat, MFloat, MFloat, MFloat, int, int, unsigned char*, int, bool, bool) const {
     return true;
 }
 
@@ -1079,6 +1079,58 @@ void BaseDriver::redisplay(const BinaryObject& binary) const {
                     l.maxY(maxy);
                     project(l);
                 } break;
+
+                case 'J': {
+                    MFloat x, y, w, h;
+                    ImageProperties::OriginReference r;
+                    in.read((char*)(&x), sizeof(double));
+                    in.read((char*)(&y), sizeof(double));
+                    in.read((char*)(&w), sizeof(double));
+                    in.read((char*)(&h), sizeof(double));
+                    in.read((char*)(&r), sizeof(ImageProperties::OriginReference));
+
+                    int len;
+                    in.read((char*)(&len), sizeof(int));
+                    char* tex = new char[len + 1];
+                    in.read(tex, sizeof(char) * len);
+                    tex[len] = '\0';
+                    string format(tex);
+
+                    in.read((char*)(&len), sizeof(int));
+                    char* tex2 = new char[len + 1];
+                    in.read(tex2, sizeof(char) * len);
+                    tex2[len] = '\0';
+                    string path(tex2);
+
+                    ImportObject obj;
+                      obj.setOrigin(PaperPoint(x,y));
+                      obj.setWidth(w);
+                      obj.setHeight(h);
+                      obj.setOriginReference(r);
+                      obj.setFormat(format);
+                      obj.setPath(path);
+
+                    MagLog::debug() << "BaseDriver::redisplayBinary for ImportObject is CALLED. "<<w<<"x"<<h<< std::endl;
+                    renderImage(obj);
+                } break;
+
+                case 'M': {             // Pixmap
+                    MFloat x0, x1, y0, y1;
+                    int wid, hei, landscape;
+                    in.read((char*)(&x0), sizeof(double));
+                    in.read((char*)(&y0), sizeof(double));
+                    in.read((char*)(&x1), sizeof(double));
+                    in.read((char*)(&y1), sizeof(double));
+                    in.read((char*)(&wid), sizeof(int));
+                    in.read((char*)(&hei), sizeof(int));
+                    in.read((char*)(&landscape), sizeof(int));
+                    MagLog::debug() << "BaseDriver::redisplayBinary for pixmap is CALLED. "<<wid<<"x"<<hei<< std::endl;
+                    const int d = wid * hei * 4;
+                    unsigned char* pixmap = new unsigned char[d];
+                    in.read((char*)(pixmap), sizeof(unsigned char) * d);
+                    renderPixmap(x0, y0, x1, y1, wid, hei, pixmap, landscape, true, true);
+                } break;
+
                 case 'U':
                     unproject();
                     break;
