@@ -78,7 +78,7 @@ void GeoJsonDriver::open() {
     if (!pFile_) {
         MagLog::error() << " GeoJsonDriver --> Cannot write output file to what was specified: " << fileName_ << endl;
         MagLog::error() << "";
-        throw NoSuchFileException("Error opening GeoJson output file!");
+        throw CannotOpenFile(fileName_);
     }
     /*	pFile_	<< "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\"?>\n"
             << "<GeoJson xmlns=\"http://www.opengis.net/GeoJson/2.2\" \n"
@@ -536,7 +536,7 @@ MAGICS_NO_EXPORT void GeoJsonDriver::renderText(const Text& text) const {}
 
 */
 MAGICS_NO_EXPORT bool GeoJsonDriver::renderPixmap(MFloat x0, MFloat y0, MFloat x1, MFloat y1, int w, int h,
-                                                  unsigned char* pixmap, int, bool) const {
+                                                  unsigned char* pixmap, int, bool, bool) const {
     debugOutput("Start renderPixmap");
     if (render_) {
         if (GeoJson_placemark_)
