@@ -122,7 +122,7 @@ private:
     MAGICS_NO_EXPORT void renderText(const Text& text) const;
     MAGICS_NO_EXPORT void circle(const MFloat x, const MFloat y, const MFloat r, const int) const;
     MAGICS_NO_EXPORT void renderImage(const ImportObject&) const;
-    MAGICS_NO_EXPORT bool renderPixmap(MFloat, MFloat, MFloat, MFloat, int, int, unsigned char*, int, bool) const;
+    MAGICS_NO_EXPORT bool renderPixmap(MFloat, MFloat, MFloat, MFloat, int, int, unsigned char*, int, bool, bool) const;
     MAGICS_NO_EXPORT bool renderCellArray(const Image& obj) const;
     MAGICS_NO_EXPORT void renderSymbols(const Symbol&) const;
 
