@@ -16,9 +16,16 @@
 
 #define MV_CODES_CHECK(a, msg) codesCheck(#a, __FILE__, __LINE__, a, msg)
 
-std::vector<MvBufrElementTable*> MvBufrElementTable::tables_;
+#ifdef METVIEW_BUFR
+namespace metview {
+static std::vector<MvBufrElementTable*> bufrElementTableItems;
+}
+#else
+static std::vector<MvBufrElementTable*> bufrElementTableItems;
+#endif
 
-bool codesCheck(const char* call, const char* file, int line, int e, const char* msg) {
+bool codesCheck(const char* call, const char* file, int line, int e, const char* msg)
+{
     if (e) {
         std::cout << call << grib_get_error_message(e);
         return false;
@@ -26,30 +33,44 @@ bool codesCheck(const char* call, const char* file, int line, int e, const char*
     return true;
 }
 
-MvBufrElementTable::MvBufrElementTable(MvBufrEdition* edition) : edition_(edition) {
+MvBufrElementTable::MvBufrElementTable(MvBufrEdition* edition) :
+    edition_(edition)
+{
     // Build descriptor-key table
     buildElementTable();
 
     // Store myself
-    tables_.push_back(this);
+#ifdef METVIEW_BUFR
+    metview::bufrElementTableItems.push_back(this);
+#else
+    bufrElementTableItems.push_back(this);
+#endif
 }
 
-MvBufrElementTable::~MvBufrElementTable() {
-    // items_.clear();
-    // maybe something else???
+MvBufrElementTable::~MvBufrElementTable()
+{
+    std::cout << "delete element" << std::endl;
+    edition_ = nullptr;
+    melems_.clear();
 }
 
-MvBufrElementTable* MvBufrElementTable::find(MvBufrEdition* edition) {
-    for (std::vector<MvBufrElementTable*>::const_iterator it = tables_.begin(); it != tables_.end(); ++it) {
-        if ((*it)->edition_ == edition)
-            return *it;
+MvBufrElementTable* MvBufrElementTable::find(MvBufrEdition* edition)
+{
+#ifdef METVIEW_BUFR
+    for(auto item: metview::bufrElementTableItems) {
+#else
+    for(auto item: bufrElementTableItems) {
+#endif
+        if (item->edition_ == edition)
+            return item;
     }
 
     MvBufrElementTable* elem = new MvBufrElementTable(edition);
     return elem;
 }
 
-const std::string& MvBufrElementTable::keyName(int descriptor)  // const
+const std::string&
+MvBufrElementTable::keyName(int descriptor)  //const
 {
     static std::string emptyStr;
 
@@ -126,7 +147,8 @@ std::cout << it->second << std::endl;
 
 typedef std::map<int, std::string> map_bufr_table;
 
-static map_bufr_table create_map() {
+static map_bufr_table create_map()
+{
     map_bufr_table map;
 
     map[1001]  = "blockNumber";
@@ -1724,7 +1746,8 @@ static map_bufr_table create_map() {
     return map;
 }
 
-bool MvBufrElementTable::buildElementTable() {
+bool MvBufrElementTable::buildElementTable()
+{
     melems_ = create_map();
     return true;
 }
