@@ -29,17 +29,20 @@ ObsJSon::~ObsJSon() {}
 
 
 CustomisedPoint* ObsJSon::decode(ValueMap& point) {
+
     CustomisedPoint* current = new CustomisedPoint();
     for (auto key = point.begin(); key != point.end(); ++key) {
         map<string, ObsJSon::Method>::iterator method = methods_.find(key->first);
+        
         if (method != methods_.end()) {
             (this->*method->second)(key->second, *current);
         }
         else {
-            if (key->second.isDouble())
+            
+            if (key->second.isDouble()) {
+               
                 (*current)[key->first] = key->second.get_value<double>();
-            if (key->second.isNumber())
-                (*current)[key->first] = long(key->second);
+            }
         }
     }
 
@@ -48,6 +51,7 @@ CustomisedPoint* ObsJSon::decode(ValueMap& point) {
 
 
 void ObsJSon::decode() {
+     
     points_.clear();
     Value value;
     if (!values_.empty()) {
@@ -59,11 +63,16 @@ void ObsJSon::decode() {
     }
 
     try {
+       
+        
         Value value = JSONParser::decodeFile(path_);
 
+        
+
         ValueMap object = value.get_value<ValueMap>();
 
         for (auto entry = object.begin(); entry != object.end(); ++entry) {
+            
             ValueList points = entry->second.get_value<ValueList>();
 
             for (unsigned int i = 0; i < points.size(); i++) {
@@ -102,6 +111,7 @@ void ObsJSon::customisedPoints(const Transformation&, const std::set<string>& wh
     for (vector<CustomisedPoint*>::const_iterator point = points_.begin(); point != points_.end(); ++point) {
         out.push_back(*point);
     }
+
 }
 void ObsJSon::customisedPoints(const Transformation& t, const std::set<string>& n, CustomisedPointsList& out,
                                bool all) {
